from ._CRUD_classes import authentication, dataset, experiment, project
from ._manual_ops import actions
from ._version import __version__

# module level doc-string
__doc__ = '''
alchemyml - Automation of data lifecycle
========================================

**alchemyml** is a tool for automating the data lifecycle and accelerating 
advanced data analysis processes. 

AlchemyML es una herramienta para automatizar el ciclo de vida del dato y 
acelerar procesos de analítica avanzada de datos. Partiendo de la ingesta y 
preparación del dato, pasando por el preprocesamiento y hasta llegar a la 
construcción de modelos predictivos, AlchemyML provee al científico de datos 
de herramientas para acelerar su 

'''


# EXAMPLE OF pandas
"""
pandas - a powerful data analysis and manipulation library for Python
=====================================================================

**pandas** is a Python package providing fast, flexible, and expressive data
structures designed to make working with "relational" or "labeled" data both
easy and intuitive. It aims to be the fundamental high-level building block for
doing practical, **real world** data analysis in Python. Additionally, it has
the broader goal of becoming **the most powerful and flexible open source data
analysis / manipulation tool available in any language**. It is already well on
its way toward this goal.

Main Features
-------------
Here are just a few of the things that pandas does well:

  - Easy handling of missing data in floating point as well as non-floating
    point data.
  - Size mutability: columns can be inserted and deleted from DataFrame and
    higher dimensional objects
  - Automatic and explicit data alignment: objects can be explicitly aligned
    to a set of labels, or the user can simply ignore the labels and let
    `Series`, `DataFrame`, etc. automatically align the data for you in
    computations.
  - Powerful, flexible group by functionality to perform split-apply-combine
    operations on data sets, for both aggregating and transforming data.
  - Make it easy to convert ragged, differently-indexed data in other Python
    and NumPy data structures into DataFrame objects.
  - Intelligent label-based slicing, fancy indexing, and subsetting of large
    data sets.
  - Intuitive merging and joining data sets.
  - Flexible reshaping and pivoting of data sets.
  - Hierarchical labeling of axes (possible to have multiple labels per tick).
  - Robust IO tools for loading data from flat files (CSV and delimited),
    Excel files, databases, and saving/loading data from the ultrafast HDF5
    format.
  - Time series-specific functionality: date range generation and frequency
    conversion, moving window statistics, moving window linear regressions,
    date shifting and lagging, etc.
"""


dict_urlData = {'get_api_token': '/token/',
                'preprocessed': '/experiments/preprocessed/',
                'predictions': '/experiments/predictions/',
                'historical_predictions': '/experiments/historical-predictions/',
                'historical_data_agg': '/experiments/historical-data-aggregations/',
                'list_preprocessed_dataframes': '/manual-ops/list-preprocessed-dataframes/',
                'download_dataframe': '/manual-ops/download-dataframe/',
                'prepare_dataframe': '/manual-ops/prepare-dataframe/',
                'encode_dataframe': '/manual-ops/encode-dataframe/',
                'drop_highly_correlated_components': '/manual-ops/drop-highly-correlated-components/',
                'impute_inconsistencies': '/manual-ops/impute-inconsistencies/',
                'drop_invalid_columns': '/manual-ops/drop-invalid-columns/',
                'target_column_analysis': '/manual-ops/target-column-analysis/',
                'balancing_dataframe': '/manual-ops/balance-dataframe/',
                'initial_exp_info': '/manual-ops/initial-exp-info/',
                'impute_missing_values': '/manual-ops/impute-missing-values/',
                'merge_cols_into_dt_index': '/manual-ops/merge-cols-into-dt-index/',
                'detect_experiment_type': '/manual-ops/detect-experiment-type/',
                'build_model': '/manual-ops/build-model/',
                'detect_outliers': '/manual-ops/detect-outliers/',
                'download_properties_df': '/manual-ops/download-properties/',
                'operational_info': '/manual-ops/operational-info/',
                'impute_outliers': '/manual-ops/impute-outliers/',
                'dataset.upload': '/datasets/upload/',
                'dataset.view': '/datasets/list/',
                'dataset.update': '/datasets/update/',
                'dataset.delete': '/datasets/delete/',
                'dataset.statistical_descriptors': '/datasets/statistical-descriptors/',
                'experiment.create': '/experiments/create/',
                'experiment.view': '/experiments/list/',
                'experiment.update': '/experiments/update/',
                'experiment.delete': '/experiments/delete/',
                'experiment.statistical_descriptors': '/experiments/statistical-descriptors/',
                'experiment.results': '/experiments/results/',
                'experiment.add_to_project': '/experiments/add-experiment-to-project/',
                'experiment.extract_from_project': '/experiments/extract-experiment-from-project/',
                'experiment.send': '/experiments/send-experiment/',
                'project.create': '/projects/create/',
                'project.view': '/projects/list/',
                'project.update': '/projects/update/',
                'project.delete': '/projects/delete/'}